{% load staticfiles %}
{% load sekizai_tags %}
{% load menu_tags %}
{% load i18n %}
{% load socialschools_tags %}

<!DOCTYPE html>
<html>
    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
        <meta name="csrf-token" content="{{csrf_token}}">

        <title>{% block _title %}{% endblock %}</title>

        <meta name="description" content="{% block _description %}{% endblock %}">
        <meta name="keywords" content="{% block _keywords %}{% endblock %}">
        <meta name="author" content="Changer">

        {% if debug %}
            <link rel="stylesheet/less" type="text/css" href="{% static 'css/styles.less' %}">
            <script src="{% static 'js/less.1.3.3.min.js' %}"></script>
        {% else %}
            <link rel="stylesheet" type="text/css" href="{% static 'css/styles.css' %}">
        {% endif %}

        {% render_block 'css' %}
    </head>
    <body>
        <div class="footer-row">
            <div class="css-topbar">
                <div class="css-stripes">
                    <div class="css-stripe stripe-1"></div>
                    <div class="css-stripe stripe-2"></div>
                    <div class="css-stripe stripe-3"></div>
                    <div class="css-stripe stripe-1"></div>
                    <div class="css-stripe stripe-2"></div>
                </div>
                <div class="container">
                    <img class="school-logo" src="{% static 'css/img/school-logo.png' %}">
                    {% socialschools_login %}
                </div>
            </div>
            <div class="navbar">
                <div class="navbar-inner css-navbar">
                    <div class="container">
                    {% block navbar%}
                    <ul class="nav">
                        {% show_menu 0 0 0 100 "socialschools_cms/menu/menu.html" %}
                    </ul>
                    {% endblock %}
                    </div>
                </div>
            </div>
        </div>
        <div class="footer-row-expand">
            <div class="container">
                {% block wrapper %}
                {% endblock %}
            </div>
        </div>

        <footer class="footer-row css-footer">
            {% block footer %}
            <div class="container">
                {% show_menu 0 1 1 100 "socialschools_cms/footer.html" %}
            </div>
            {% endblock %}
        </footer>
        <script type="text/javascript" src="{% static 'js/jquery.1.9.1.min.js' %}"></script>
        <script type="text/javascript" src="{% static 'js/bootstrap.min.js' %}"></script>
        <script type="text/javascript" src="{% static 'js/socialschools-cms.js' %}"></script>
        {% render_block 'js' %}
    </body>
</html>
